// Please see credits and usage for usiTwiSlave and TinyWireS in the .h files of 
// those libraries.

#include <avr/sleep.h>
#include <avr/wdt.h>
#include "TinyWireS.h"                  

uint8_t i2c_address = 0x04;

                    // Pin 1 - Reserved for Reset
uint8_t SER = 3;    // Pin 2 - SER to 74HC595 
uint8_t SRCLK = 4;  // Pin 3 - SRCLK to 74HC595
                    // Pin 4 - Gnd
                    // Pin 5 - SDA
uint8_t RCLK = 1;   // Pin 6 - RCLK to 74HC595
                    // Pin 7 - SCL
                    // Pin 8 - Vcc

void setup()
{
  pinMode(SER,OUTPUT);                                  //Configure PB3 as output
  pinMode(RCLK,OUTPUT);                                 //Configure PB1 as output
  pinMode(SRCLK,OUTPUT);                                //Configure PB4 as output
  

  //Clear any junk data from the Shift Registers
  digitalWrite(SER, 0);                                 //Set SER line LOW
  digitalWrite(RCLK, 0);                                //Set RCLK line LOW
  digitalWrite(SRCLK, 0);                               //Set SRCLK line LOW

  for(int x = 0; x<(8*6);x++){                          // For each settable bit in the Shift-registers 8-bits * 6 ICs
    digitalWrite(SRCLK, 1);                             // Clock the Serial Clock line High 
    digitalWrite(SRCLK, 0);                             // Clock the Serial Clock line Low
  }
  digitalWrite(RCLK, 1);                                // Pulse the RLCK to clear any junk data on the output pins.
  digitalWrite(RCLK, 0);                                

  TinyWireS.begin(i2c_address);                         // Initiazlize the I2C Slave mode
  TinyWireS.onReceive(receiveEvent);                    // Register the onReceive() callback function
}

void loop()
{
}

// Gets called when the ATtiny receives an i2c write slave request
// This routine runs from the usiTwiSlave interrupt service routine (ISR)
// so interrupts are disabled while it runs.
void receiveEvent(uint8_t num_bytes)
{
  uint8_t display_byte[16];
  uint8_t master_bytes = num_bytes;

  for (uint8_t i = 0; i < master_bytes; i++){           // Process each byte of data from the master
    display_byte[i] = TinyWireS.receive();
    for (uint8_t x = 0; x < 8; x++){                    //Loop for each bit within data byte
      digitalWrite(SER, bitRead(display_byte[i], x));   //Set the SER pin based on the bit of data
      digitalWrite(SRCLK, 1);                           //Set SRCLK High
      digitalWrite(SRCLK, 0);                           //Set SRCLK Low
    }
  }     
  digitalWrite(RCLK, 1);                                // Pulse the RLCK to data on the output pins.
  digitalWrite(RCLK, 0);                                
}

